body {
  margin: 0;
}
.main {
  font-family: "Noto Sans JP", sans-serif;
  max-width: 1440px;
  font-weight: 400;
  line-height: 1.5;
  margin: 0 auto;
  font-size: 16px;
  color: #5F2314;
}
.main * {
  font-family: "Noto Sans JP", sans-serif !important;
}
.main .icon_buy {
  position: fixed;
  right: 20px;
  bottom: 130px;
  z-index: 2;
}
.main .icon_buy:hover {
  cursor: pointer;
}
@media screen and (max-width:767px) {
  .main .icon_buy {
    width: 25.64vw;
    right: 2.56vw;
  }
}
.icon_buy.is-hide {
  display: none;
}
.icon_buy__hide {
  position: absolute;
  right: 10px;
  top: 10px;
}
@media screen and (max-width:767px) {
  .icon_buy__hide {
    width: 4.7vw;
    right: .5rem;
    top: .5rem;
  }
}
.sec1 {
  background-image: url(/home/brands/dolce-gusto/sites/default/files/brand/ndg/campaign/ice2026/img/pc/bg_01.jpg);
  background-repeat: no-repeat;
  background-size: cover;
  position: relative;
  padding: 190px 0;
}
@media screen and (max-width:1439px) {
  .sec1 {
    padding: 13.19vw;
  }
}
@media screen and (max-width:767px) {
  .sec1 {
    background-image: url(/home/brands/dolce-gusto/sites/default/files/brand/ndg/campaign/ice2026/img/sp/bg_01.jpg);
    padding: 53vw 0 10vw;
  }
}
.sec1__beans {
  position: absolute;
  top: 0;
  left: 0;
  z-index: 1;
}
.sec1__ice {
  position: absolute;
  z-index: 1;
}
.sec1__ice--1 {
  top: 240px;
  right: 154px;
}
@media screen and (max-width:1439px) {
  .sec1__ice--1 {
    top: 16.67vw;
    right: 10.69%;
    width: 12.5vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__ice--1 {
    top: 44vw;
    right: 0;
    width: 19vw;
  }
}
.sec1__ice--2 {
  top: 760px;
  left: 180px;
}
@media screen and (max-width:1439px) {
  .sec1__ice--2 {
    top: 52.78vw;
    left: 12.5vw;
    width: 10.14vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__ice--2 {
    top: 259vw;
    left: 1vw;
    width: 16vw;
  }
}
.sec1__ice--3 {
  top: 730px;
  left: 130px;
}
@media screen and (max-width:1439px) {
  .sec1__ice--3 {
    top: 50.69vw;
    left: 9.03vw;
    width: 8.82vw;
  }
}
.sec1__ice--4 {
  top: 1410px;
  right: 184px;
}
@media screen and (max-width:1439px) {
  .sec1__ice--4 {
    top: 97.92vw;
    right: 12.78vw;
    width: 8.06vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__ice--4 {
    top: 270vw;
    right: 0vw;
    width: 13vw;
  }
}
.sec1__ice--5 {
  top: 1490px;
  right: 204px;
}
@media screen and (max-width:1439px) {
  .sec1__ice--5 {
    top: 103.47vw;
    right: 14.17vw;
    width: 6.81vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__ice--5 {
    top: 280vw;
    right: 4vw;
    width: 11vw;
  }
}
.sec1__ice--6 {
  top: 2520px;
  left: 176px;
}
@media screen and (max-width:1439px) {
  .sec1__ice--6 {
    top: 175vw;
    left: 12.22vw;
    width: 11.18vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__ice--6 {
    top: 763vw;
    left: 2vw;
    width: 18vw;
  }
}
.sec1__ice--7 {
  top: 3206px;
  right: 176px;
}
@media screen and (max-width:1439px) {
  .sec1__ice--7 {
    top: 222.64vw;
    right: 12.22vw;
    width: 13.89vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__ice--7 {
    top: 1039vw;
    width: 23vw;
    right: 0;
  }
}
.sec1__box {
  background: #fff;
  width: 926px;
  margin: 0 auto;
  position: relative;
  padding: 40px;
}
@media screen and (max-width:1439px) {
  .sec1__box {
    width: 64.31vw;
    padding: 2.78vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box {
    width: 87vw;
    padding: 4vw 0 0;
  }
}
.sec1__box__h2 {
  font-size: 30px;
  font-weight: bold;
  text-align: center;
  line-height: 1;
  width: 330px;
  padding: 18px;
  color: #fff;
  background: #0861C5;
  border-radius: 40px;
  position: absolute;
  top: -33px;
  left: calc(50% - 330px / 2);
}
@media screen and (max-width:1439px) {
  .sec1__box__h2 {
    width: 22.92vw;
    left: calc(50% - 22.92vw / 2);
    font-size: 2.08vw;
    padding: 1.25vw;
    top: -2.29vw;
    border-radius: 3em;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__h2 {
    width: 66vw;
    left: calc(50% - 66vw / 2);
    font-size: 6.67vw;
    padding: .4em;
    top: -6vw;
  }
}
.sec1__box__h2--red {
  background: #C70000;
}
.sec1__box__h3 {
  text-align: center;
  font-size: 28px;
  font-weight: 500;
  padding: 64px 0 40px;
}
@media screen and (max-width:1439px) {
  .sec1__box__h3 {
    font-size: 1.98vw;
  padding: 4.44vw 0 2.78vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__h3 {
    font-size: 5.64vw;
    padding: 8vw 0 10vw;
  }
}
.sec1__box__h4 {
  background: #0861C5;
  color: #fff;
  font-weight: bold;
  font-size: 20px;
  text-align: center;
  line-height: 1;
  padding: 10px 0;
}
@media screen and (max-width:1439px) {
  .sec1__box__h4 {
    font-size: 1.39vw;
    padding: .69vw 0;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__h4 {
    font-size: 4.62vw;
    padding: 3.5vw 0;
    margin: 0 4vw;
  }
}
.sec1__box__img01 {
  text-align: center;
  padding: 40px 0;
}
@media screen and (max-width:1439px) {
  .sec1__box__img01 {
    padding: 2.78vw 0;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__img01 {
    margin: 0 4vw;
    padding: 8vw 0;
  }
}
@media screen and (max-width:1439px) {
  .sec1__box__img01 picture {
    width: 47.89vw;
    display: block;
    margin: 0 auto;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__img02 {
    margin: 0 4vw;
  }
}
.sec1__box__app {
  background: #F4F0EF;
  margin-top: 40px;
  padding: 32px 24px;
}
@media screen and (max-width:1439px) {
  .sec1__box__app {
  margin-top: 2.78vw;
  padding: 2.22vw 1.67vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__app {
    padding: 8vw 4vw;
  }
}
.sec1__box__app__h3 {
  font-size: 24px;
  font-weight: 500;
  padding-bottom: 24px;
}
@media screen and (max-width:1439px) {
  .sec1__box__app__h3 {
    font-size: 1.67vw;
  padding-bottom: 1.67vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__app__h3 {
    font-size: 5.64vw;
  }
}
.sec1__box__app__box {
  background: #fff;
  padding: 24px 40px;
  margin-bottom: 24px;
}
@media screen and (max-width:1439px) {
  .sec1__box__app__box {
    padding: 1.67vw 2.78vw;
    margin-bottom: 1.67vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__app__box {
    margin: 8vw 0;
    padding: 4vw;
  }
  .sec1__box__app__box .flex {
    display: block;
  }
}
.sec1__box__app__box__ttl {
  display: flex;
  align-items: center;
  padding-bottom: 30px;
}
@media screen and (max-width:1439px) {
  .sec1__box__app__box__ttl {
    padding-bottom: 2.08vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__app__box__ttl {
    display: block;
    text-align: center;
  }
}
@media screen and (max-width:1439px) {
  .sec1__box__app__box__ttl__logo {
    width: 4.65vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__app__box__ttl__logo {
    width: 17.18vw;
    margin: 4vw auto;
  }
}
.sec1__box__app__box__ttl__h4 {
  color: #DA562F;
  font-weight: bold;
  font-size: 16px;
}
@media screen and (max-width:1439px) {
  .sec1__box__app__box__ttl__h4 {
    font-size: 1.11vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__app__box__ttl__h4 {
    font-size: 4.1vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__app__box__ttl__h4 {
    padding-top: 4vw;
  }
}
.sec1__box__app__box__ttl__h4 span {
  font-size: 20px;
}
@media screen and (max-width:1439px) {
  .sec1__box__app__box__ttl__h4 span {
    font-size: 1.39vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__app__box__ttl__h4 span {
    font-size: 4.87vw;
  }
}
.sec1__box__app__box__link {
  display: flex;
  align-items: center;
}
@media screen and (max-width:767px) {
  .sec1__box__app__box__link {
    justify-content: center;
    margin-top: 8vw;
  }
}
.sec1__box__app__box__link__qr {
  margin-right: 20px;
}
@media screen and (max-width:1439px) {
  .sec1__box__app__box__link__qr {
    flex: none;
    margin-right: 1.39vw;
    width: 5.97vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__app__box__link__qr {
    width: 22.05vw;
    margin-right: 4vw;
  }
}
.sec1__box__app__box__link__store div {
  padding: 4px 0;
}
@media screen and (max-width:1439px) {
  .sec1__box__app__box__link__store div:first-of-type {
    width: 10.9vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__app__box__link__store div:first-of-type {
    width: 40.26vw;
  }
}
@media screen and (max-width:1439px) {
  .sec1__box__app__box__link__store div:last-of-type {
    width: 8.61vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__app__box__link__store div:last-of-type {
    width: 31.79vw;
  }
}
.sec1__box__device {
  display: flex;
  color: #5A2400;
  align-items: center;
  font-weight: 500;
}
@media screen and (max-width:767px) {
  .sec1__box__device {
    display: block;
  }
}
.sec1__box__device__ttl {
  border: 1px solid #5A2400;
  font-size: 14px;
  padding: 10px 14px;
  margin-right: 14px;
}
@media screen and (max-width:1439px) {
  .sec1__box__device__ttl {
    font-size: .97vw;
    padding: .69vw .97vw;
    margin-right: .97vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__device__ttl {
    width: 30.77vw;
    font-size: 3.59vw;
    text-align: center;
    padding: 2vw;
    margin-bottom: 4vw;
  }
}
.sec1__box__device__a {
  font-size: 12px;
  text-decoration: underline;
  color: inherit;
}
@media screen and (max-width:1439px) {
  .sec1__box__device__a {
    font-size: .83vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__device__a {
    font-size: 4.62vw;
  }
}
.sec1__box-outer {
  max-width: 926px;
  margin: 100px auto;
  justify-content: space-between;
  display: flex;
}
@media screen and (max-width:1439px) {
  .sec1__box-outer {
    width: 64.31vw;
    margin: 6.94vw auto;
  }
}
@media screen and (max-width:767px) {
  .sec1__box-outer {
    width: 87vw;
    display: block;
    margin-top: 0;
  }
}
.sec1__box-outer .sec1__box {
  width: 48%;
  margin: 0;
}
@media screen and (max-width:767px) {
  .sec1__box-outer .sec1__box {
    width: 100%;
    padding: 4vw 0;
    margin: 16vw 0;
  }
}
.sec1__box-outer .sec1__box .sec1__box__txt {
  font-size: 28px;
  text-align: center;
  padding-top: 24px;
  font-weight: 500;
}
@media screen and (max-width:1439px) {
  .sec1__box-outer .sec1__box .sec1__box__txt {
    font-size: 1.94vw;
    padding-top: 1.67vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box-outer .sec1__box .sec1__box__txt {
    font-size: 6.15vw;
  }
}
.sec1__box-outer .sec1__box .sec1__box__txt span {
  font-size: 36px;
  color: #C70000;
}
@media screen and (max-width:1439px) {
  .sec1__box-outer .sec1__box .sec1__box__txt span {
    font-size: 2.5vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box-outer .sec1__box .sec1__box__txt span {
    font-size: 9.28vw;
  }
}
.sec1__box__note {
  list-style: none;
  margin: 32px 0;
}
@media screen and (max-width:1439px) {
  .sec1__box__note {
    margin: 2.22vw 0;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__note {
    font-size: 3.84vw;
    padding: 0 4vw;
  }
}
.sec1__box__note li {
  line-height: 2;
  font-size: 20px;
  text-indent: -1em;
  padding-left: 1em;
}
@media screen and (max-width:1439px) {
  .sec1__box__note li {
    font-size: 1.39vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__note li {
    font-size: 5.13vw;
  }
}
.sec1__box__note li a {
  color: #0861C5;
  text-decoration: underline;
}
.sec1__box__btn {
  text-align: center;
}
@media screen and (max-width:1439px) {
  .sec1__box__btn {
    width: 28.75vw;
    margin: 0 auto;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__btn {
    padding: 0 0 8vw;
    width: 75.38vw;
    margin: 0 auto;
  }
}
@media screen and (max-width:1439px) {
  .sec1__box__app__box__machine--1 {
    flex: none;
    width: 15.63vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__app__box__machine--1 {
    width: 51.28vw;
    margin: 0 auto;
  }
}
@media screen and (max-width:1439px) {
  .sec1__box__app__box__machine--2 {
    flex: none;
    width: 25.69vw;
  }
}
@media screen and (max-width:767px) {
  .sec1__box__app__box__machine--2 {
    width: 70.26vw;
    margin: 0 auto;
  }
}
.sec3 {
  background: #fff;
}
@media screen and (max-width:1439px) {
  .sec3 {
    padding: 4.8vw 4vw 0;
  }
}
.sec3__note {
  font-size: 16px;
  font-weight: 500;
  text-align: center;
  text-indent: -1em;
  padding-left: 1em;
}
@media screen and (max-width:1439px) {
  .sec3__note {
    font-size: 1.11vw;
  }
}
@media screen and (max-width:767px) {
  .sec3__note {
    text-align: left;
    font-size: 4.1vw;
    margin: 4vw 0 16vw;
  }
}
.sec3__h {
  text-align: center;
  margin-top: 60px;
}
@media screen and (max-width:1439px) {
  .sec3__h {
    margin-top: 4.1vw;
    padding: 0;
  }
}
.sec3__items {
  list-style: none;
  display: flex;
  justify-content: space-around;
  max-width: 80%;
  margin: 60px auto 0;
}
@media screen and (max-width:1439px) {
  .sec3__items {
    margin-top: 4.1vw;
  }
  .sec3__items li {
    width: 18.9vw;
  }
}
@media screen and (max-width:767px) {
  .sec3__items {
    flex-wrap: wrap;
    max-width: 90%;
  }
  .sec3__items li {
    width: 41.02vw;
    margin-bottom: 3.84vw
  }
}
.sec3__items li.linebreak {
  width: 100%;
}
.sec3__dialog-bg.is-open {
  width: 100vw;
  height: 100vh;
  position: fixed;
  background: #000;
  top: 0;
  left: 0;
  opacity: .2;
  z-index: 2;
}
.sec3__dialog {
  position: fixed;
  top: calc(50% - 130px);
  left: calc(50% - 210px);
  border: none;
  outline: none;
  border-radius: 8px;
  width: 420px;
  height: 260px;
  background: #fff;
  display: none;
  flex-wrap: wrap;
  align-items: center;
  justify-content: center;
  z-index: 3;
}
@media screen and (max-width:767px) {
  .sec3__dialog {
    width: 76.92vw;
    left: calc(50% - 38.46vw);
    height: 48.71vw;
  }
}
.sec3__dialog.is-open {
  display: flex;
}
.sec3__dialog__close {
  position: absolute;
  top: -15px;
  right: -15px;
}
.sec3__dialog__close:hover {
  cursor: pointer;
}
@media screen and (max-width:767px) {
  .sec3__dialog .link {
    width: 86%;
  }
}
.sec3__btn {
  text-align: center;
  margin-top: 100px;
}
@media screen and (max-width:1439px) {
  .sec3__btn {
    margin: 6.94vw auto 0;
    width: 28.75vw;
  }
}
@media screen and (max-width:767px) {
  .sec3__btn {
    margin: 20vw auto 40vw;
    width: 75.38vw;
  }
}
.btn:hover {
  cursor: pointer;
}